from resotolib.args import ArgumentParser
from resotolib.core import resotocore, add_args
from resotometrics.config import _load_default_metrics, MetricType


def test_args():
    arg_parser = ArgumentParser(description="resoto metrics exporter", env_args_prefix="RESOTOMETRICS_")
    add_args(arg_parser)
    arg_parser.parse_args()
    assert resotocore.http_uri == "https://localhost:8900"
    assert resotocore.ws_uri == "wss://localhost:8900"


def test_default_config() -> None:
    metrics = _load_default_metrics()
    assert len(metrics) > 1
    first = next(iter(metrics.values()))
    assert isinstance(first.type, MetricType)



import resotometrics
from setuptools import setup, find_packages


with open("requirements.txt") as f:
    requirements = f.read().splitlines()

with open("README.md") as f:
    readme = f.read()


setup(
    name=resotometrics.__title__,
    version=resotometrics.__version__,
    description=resotometrics.__description__,
    license=resotometrics.__license__,
    packages=find_packages(),
    long_description=readme,
    long_description_content_type="text/markdown",
    entry_points={
        "console_scripts": [
            "resotometrics = resotometrics.__main__:main",
        ]
    },
    include_package_data=True,
    zip_safe=False,
    install_requires=requirements,
    setup_requires=["pytest-runner"],
    tests_require=["pytest"],
    classifiers=[
        # Current project status
        "Development Status :: 4 - Beta",
        # Audience
        "Intended Audience :: System Administrators",
        "Intended Audience :: Information Technology",
        # License information
        "License :: OSI Approved :: Apache Software License",
        # Supported python versions
        "Programming Language :: Python :: 3.9",
        # Supported OS's
        "Operating System :: POSIX :: Linux",
        "Operating System :: Unix",
        # Extra metadata
        "Environment :: Console",
        "Natural Language :: English",
        "Topic :: Security",
        "Topic :: Utilities",
    ],
    keywords="cloud security",
)
